#pragma once

// MassBuilderSaveTool
// Copyright (C) 2021 Guillaume Jacquemin
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <https://www.gnu.org/licenses/>.

#include <Corrade/Containers/Array.h>

struct StoryProgressPoint {
    Int id;
    const char* chapter;
    const char* point;
    const char* after = "";
};

static const Corrade::Containers::Array<StoryProgressPoint> story_progress
{
    InPlaceInit,
    {
        {0x0000, "Chapter 1", "Chapter start (company isn't named yet)"},
        {0x0064, "Chapter 1", "First time in the hangar"},
        {0x0065, "Chapter 1", "After 1st meeting with Quin in mission section"},
        {0x0066, "Chapter 1", "Talking with Reina and Quin in hangar",                    "After training"},
        {0x0067, "Chapter 1", "Returned to hangar",                                       "After training"},
        {0x0068, "Chapter 1", "Talked with Quin in development section",                  "After training"},
        {0x0069, "Chapter 1", "Talked with Waltz in armour section",                      "After training"},
        {0x00C8, "Chapter 1", "Talked with Kael in tuning section",                       "After training"},
        {0x00C9, "Chapter 1", "Got mission 2 briefing",                                   "After training"},
        {0x012C, "Chapter 1", "Talking with Reina",                                       "After mission 2"},
        {0x012D, "Chapter 1", "Returned to hangar",                                       "After mission 2"},
        {0x012E, "Chapter 1", "Talked with Kael in tuning section",                       "After mission 2"},
        {0x012F, "Chapter 1", "Talked with Reina in hangar",                              "After mission 2"},
        {0x0130, "Chapter 1", "Got mission 3 briefing",                                   "After mission 2"},
        {0x0190, "Chapter 1", "Talking with Reina",                                       "After mission 3"},
        {0x0191, "Chapter 1", "Returned to hangar",                                       "After mission 3"},
        {0x0192, "Chapter 1", "Talked with Waltz in armour section",                      "After mission 3"},
        {0x0193, "Chapter 1", "Got mission 4 briefing",                                   "After mission 3"},
        {0x01F4, "Chapter 1", "Talking with Reina",                                       "After mission 4"},
        {0x01F5, "Chapter 1", "Returned to hangar",                                       "After mission 4"},
        {0x01F6, "Chapter 1", "Talked with Waltz in armour section",                      "After mission 4"},
        {0x01F7, "Chapter 1", "Talked with Reina in hangar",                              "After mission 4"},
        {0x01F8, "Chapter 1", "Got mission 5 and hunt 1 briefing",                        "After mission 4"},
        {0x0258, "Chapter 1", "Meeting Neon and Aine",                                    "After mission 5"},
        {0x0259, "Chapter 1", "Returned to hangar",                                       "After mission 5"},
        {0x025A, "Chapter 1", "Got mission 6 briefing",                                   "After mission 5"},
        {0x02BC, "Chapter 1", "Talking with Reina",                                       "After mission 6"},
        {0x02BD, "Chapter 1", "Returned to hangar",                                       "After mission 6"},
        {0x02BE, "Chapter 1", "Got hunt 2 briefing",                                      "After mission 6"},
        {0x02BF, "Chapter 1", "Met Ellenier",                                             "After mission 6"},
        {0x02C0, "Chapter 1", "Got mission 7 briefing",                                   "After mission 6"},
        {0x0320, "Chapter 1", "Talking with Nier",                                        "After mission 7"},
        {0x0321, "Chapter 1", "Returned to hangar",                                       "After mission 7"},
        {0x0322, "Chapter 1", "Talked with Quin, Reina, and Nier in development section", "After mission 7"},
        {0x0323, "Chapter 1", "Got mission 8 briefing",                                   "After mission 7"},
        {0x0384, "Chapter 1", "Talking with crew in hangar",                              "After mission 8"},
        {0x0385, "Chapter 1", "Returned to hangar",                                       "After mission 8"},
        {0x0386, "Chapter 1", "Got hunt 3 briefing",                                      "After mission 8"},
        {0x0387, "Chapter 1", "Talked with Reina, Nier, and Quin in development section", "After mission 8"},

        {0x0388, "Chapter 2", "Chapter start"},
        {0x0389, "Chapter 2", "Got mission 9 briefing"},
        {0x03E8, "Chapter 2", "Talking with Reina in hangar",             "After mission 9"},
        {0x03E9, "Chapter 2", "Returned to hangar",                       "After mission 9"},
        {0x03EA, "Chapter 2", "Talked with crew in armour section",       "After mission 9"},
        {0x03EB, "Chapter 2", "Got mission 10 briefing",                  "After mission 9"},
        {0x044C, "Chapter 2", "Talking with Reina in hangar",             "After mission 10"},
        {0x044D, "Chapter 2", "Returned to hangar",                       "After mission 10"},
        {0x044E, "Chapter 2", "Got mission 11 briefing",                  "After mission 10"},
        {0x04B0, "Chapter 2", "Talking with Reina and Nier in hangar",    "After mission 11"},
        {0x04B1, "Chapter 2", "Returned to hangar",                       "After mission 11"},
        {0x04B2, "Chapter 2", "Got mission 12 briefing",                  "After mission 11"},
        {0x0514, "Chapter 2", "Talking with Reina and Waltz in hangar",   "After mission 12"},
        {0x0515, "Chapter 2", "Returned to hangar",                       "After mission 12"},
        {0x0516, "Chapter 2", "Got hunt 4 and mission 13 briefing",       "After mission 12"},
        {0x0578, "Chapter 2", "Talking with Reina in hangar",             "After mission 13"},
        {0x0579, "Chapter 2", "Returned to hangar",                       "After mission 13"},
        {0x057A, "Chapter 2", "Talked with Reina in development section", "After mission 13"},
        {0x057B, "Chapter 2", "Got briefing for challenges 1, 2, and 3",  "After mission 13"},
    }
};
