#pragma once

// MassBuilderSaveTool
// Copyright (C) 2021 Guillaume Jacquemin
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <https://www.gnu.org/licenses/>.

#include <string>
#include <vector>

#include "../Profile/Profile.h"

struct Backup {
    std::string filename;
    std::string company;
    ProfileType type;
    struct {
        int year;
        int month;
        int day;
        int hour;
        int minute;
        int second;
    } timestamp;
    std::vector<std::string> includedFiles;
};

class ProfileManager {
    public:
        explicit ProfileManager(const std::string& save_dir, const std::string& backup_dir);

        auto ready() const -> bool;
        auto lastError() -> std::string const&;

        auto profiles() -> std::vector<Profile> const&;
        auto refreshProfiles() -> bool;

        auto getProfile(std::size_t index) -> Profile*;
        auto deleteProfile(std::size_t index, bool delete_builds) -> bool;
        auto backupProfile(std::size_t index, bool backup_builds) -> bool;

        auto backups() -> std::vector<Backup> const&;
        void refreshBackups();

        auto deleteBackup(std::size_t index) -> bool;
        auto restoreBackup(std::size_t index) -> bool;

    private:
        bool _ready = false;
        std::string _lastError;

        const std::string& _saveDirectory;
        const std::string& _backupsDirectory;

        std::vector<Profile> _profiles;
        std::vector<Backup> _backups;
};
